@@ -552,8 +552,7 @@ class _CustomMLP(nn.Module):
 
     The hyperparameters that are only in CustomMLP are 'layer_{n}_dim's (for all hidden layers). 
 
-    Example::
-        >>> 
+    
 
     Args:
         
@@ -697,9 +696,7 @@ class CustomMLP(BaseNet):
 
     The hyperparameters that are only in CustomMLP are 'layer_{n}_dim's (for all hidden layers). 
 
-    Example::
-
-        >>> model = CustomMLP(dims=(1,8,8), n_classes=10, n_hidden_units_list=[30,20,10])
+    
 
     Args:
         
@@ -771,7 +768,7 @@ class CustomMLP(BaseNet):
         # n_hidden_units_list
         for n_hidden_units in hparams['n_hidden_units_list']:
             if n_hidden_units <=0:
-                raise ValueError(f"Number of hidden units can't be less than or equal to 0.")
+                raise ValueError("Number of hidden units can't be less than or equal to 0.")
 
         super(CustomMLP, self).__init__(
             dims=dims,
@@ -784,7 +781,7 @@ class CustomMLP(BaseNet):
         # sanity check. Check if right arguments are declared.
         for key in hparams.keys():
             if key not in entire_keys:
-                raise ValueError('Wrong argument is passed to the model.')
+                raise ValueError(f'Wrong argument {key} is passed to the model.')
         self.model = _CustomMLP(dims=dims, n_classes=n_classes, sample_weight=sample_weight, **hparams)
 
     def forward(self, X):
